summaryrefslogtreecommitdiffstats
path: root/korganizer/kotodoeditor.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'korganizer/kotodoeditor.cpp')
-rw-r--r--korganizer/kotodoeditor.cpp16
1 files changed, 8 insertions, 8 deletions
diff --git a/korganizer/kotodoeditor.cpp b/korganizer/kotodoeditor.cpp
index 180ff139..f996321e 100644
--- a/korganizer/kotodoeditor.cpp
+++ b/korganizer/kotodoeditor.cpp
@@ -20,8 +20,8 @@
Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
As a special exception, permission is given to link this program
- with any edition of Qt, and distribute the resulting executable,
- without including the source code for Qt in the source distribution.
+ with any edition of TQt, and distribute the resulting executable,
+ without including the source code for TQt in the source distribution.
*/
#include <tqtooltip.h>
@@ -51,8 +51,8 @@
#include "kotodoeditor.h"
#include "kocore.h"
-KOTodoEditor::KOTodoEditor( Calendar *calendar, TQWidget *parent ) :
- KOIncidenceEditor( TQString::null, calendar, parent ),
+KOTodoEditor::KOTodoEditor( Calendar *calendar, TQWidget *tqparent ) :
+ KOIncidenceEditor( TQString(), calendar, tqparent ),
mTodo( 0 ), mCalendar( 0 ), mRelatedTodo( 0 ), mGeneral( 0 ), mRecurrence( 0 )
{
}
@@ -128,7 +128,7 @@ void KOTodoEditor::setupGeneral()
mGeneral->initHeader( topFrame, topLayout );
mGeneral->initTime(topFrame,topLayout);
- mGeneral->iniStatus(topFrame,topLayout);
+ mGeneral->initqStatus(topFrame,topLayout);
mGeneral->initDescription(topFrame,topLayout);
mGeneral->initAttachments(topFrame,topLayout);
connect( mGeneral, TQT_SIGNAL( openURL( const KURL& ) ),
@@ -174,7 +174,7 @@ void KOTodoEditor::setTexts( const TQString &summary, const TQString &descriptio
{
if ( description.isEmpty() && summary.tqcontains("\n") ) {
mGeneral->setDescription( summary );
- int pos = summary.find( "\n" );
+ int pos = summary.tqfind( "\n" );
mGeneral->setSummary( summary.left( pos ) );
} else {
mGeneral->setSummary( summary );
@@ -257,7 +257,7 @@ void KOTodoEditor::setDates( const TQDateTime &due, bool allDay, Todo *relatedEv
{
mRelatedTodo = relatedEvent;
// inherit some properties from parent todo
if ( mRelatedTodo ) {
mGeneral->setCategories( mRelatedTodo->categories() );
}
@@ -306,7 +306,7 @@ void KOTodoEditor::writeTodo( Todo *todo )
}
writeDesignerFields( todo );
// set related incidence, i.e. parent to-do in this case.
if ( mRelatedTodo ) {
todo->setRelatedTo( mRelatedTodo );
}
@@ -257,7 +257,7 @@ void KOTodoEditor::setDates( const TQDateTime &due, bool allDay, Todo *relatedEv
{
mRelatedTodo = relatedEvent;
- // inherit some properties from parent todo
+ // inherit some properties from tqparent todo
if ( mRelatedTodo ) {
mGeneral->setCategories( mRelatedTodo->categories() );
@@ -306,7 +306,7 @@ void KOTodoEditor::writeTodo( Todo *todo )
}
writeDesignerFields( todo );
- // set related incidence, i.e. parent to-do in this case.
+ // set related incidence, i.e. tqparent to-do in this case.
if ( mRelatedTodo ) {
todo->setRelatedTo( mRelatedTodo );